Clayton.Markov.MLE.binom: Maximum Likelihood Estimation and Statistical Process Control Under the Clayton Copula
Description
The maximum likelihood estimates are produced and the Shewhart control chart is drawn with k-sigma control limits (e.g., 3-sigma). The dependence model follows the Clayton copula and the marginal (stationary) distribution follows the normal distribution.
Usage
Clayton.Markov.MLE.binom(Y, size, k = 3, method="nlm", plot = TRUE, GOF=FALSE)
Arguments
Y
vector of observations
size
numbe of binomial trials
method
nlm or Newton
k
constant determining the length between LCL and UCL (k=3 corresponds to 3-sigma limit)
plot
show the control chart if TRUE
GOF
show the model diagnostic plot if TRUE
Value
p
estimate, SE, and 95 percent CI
alpha
estimate, SE, and 95 percent CI
Control_Limit
Center = n*p, LCL = mu - k*sigma, UCL = mu + k*sigma
out_of_control
IDs for out-of-control points
Gradient
gradients (must be zero)
Hessian
Hessian matrix
Eigenvalue_Hessian
Eigenvalues for the Hessian matrix
KS.test
KS statistics
CM.test
CM statistics
log_likelihood
Log-likelihood value for the estimation
References
Chen W (2018) Copula-based Markov chain model with binomial data, NCU Library
Huang XW, Emura T (2021-), Computational methods for a copula-based Markov chain model with
a binomial time series, in review
# NOT RUN {size=50prob=0.5alpha=2set.seed(1)
Y=Clayton.Markov.DATA.binom(n=500,size,prob,alpha)
Clayton.Markov.MLE.binom(Y,size=size,k=3,plot=TRUE)
# }